==> haskell-getopt-generics-0.13.1.0-116-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-getopt-generics.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 getopt-generics
version:              0.13.1.0
visibility:           public
id:                   getopt-generics-0.13.1.0-FNAGGR0dU9n9snf6aZnUiQ
key:                  getopt-generics-0.13.1.0-FNAGGR0dU9n9snf6aZnUiQ
license:              BSD-3-Clause
copyright:            Zalora South East Asia Pte Ltd
maintainer:           linh.nguyen@zalora.com, soenkehahn@gmail.com
author:               Linh Nguyen, Sönke Hahn
homepage:             https://github.com/soenkehahn/getopt-generics#readme
synopsis:             Create command line interfaces with ease
description:          Create command line interfaces with ease
category:             Console, System
abi:                  522125cbd1c57f44066dc8e766a8c04d
exposed:              True
exposed-modules:      WithCli WithCli.Pure
hidden-modules:
    WithCli.Argument WithCli.Flag WithCli.HasArguments WithCli.Modifier
    WithCli.Modifier.Types WithCli.Normalize WithCli.Parser
    WithCli.Pure.Internal WithCli.Result Paths_getopt_generics

import-dirs:          /usr/lib/ghc-9.4.8/site-local/getopt-generics-0.13.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/getopt-generics-0.13.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/getopt-generics-0.13.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-getopt-generics
hs-libraries:         HSgetopt-generics-0.13.1.0-FNAGGR0dU9n9snf6aZnUiQ
depends:
    base-4.17.2.1 base-compat-0.14.0-D6ySGt5shRqHRPQXrHl9Oo
    base-orphans-0.9.3-KjEwzlW93pECocqzLBwG3l
    generics-sop-0.5.1.3-1cdm4H81rvrYJuJwoMQFY
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C

haddock-interfaces:
    /usr/share/doc/haskell-getopt-generics/html/getopt-generics.haddock

haddock-html:         /usr/share/doc/haskell-getopt-generics/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-getopt-generics-0.13.1.0-117-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-getopt-generics.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 getopt-generics
version:              0.13.1.0
visibility:           public
id:                   getopt-generics-0.13.1.0-45xXbNY05ppCTHFFBbj3aP
key:                  getopt-generics-0.13.1.0-45xXbNY05ppCTHFFBbj3aP
license:              BSD-3-Clause
copyright:            Zalora South East Asia Pte Ltd
maintainer:           linh.nguyen@zalora.com, soenkehahn@gmail.com
author:               Linh Nguyen, Sönke Hahn
homepage:             https://github.com/soenkehahn/getopt-generics#readme
synopsis:             Create command line interfaces with ease
description:          Create command line interfaces with ease
category:             Console, System
abi:                  f3778e4d17668df6b0d514a599adfdc6
exposed:              True
exposed-modules:      WithCli WithCli.Pure
hidden-modules:
    WithCli.Argument WithCli.Flag WithCli.HasArguments WithCli.Modifier
    WithCli.Modifier.Types WithCli.Normalize WithCli.Parser
    WithCli.Pure.Internal WithCli.Result Paths_getopt_generics

import-dirs:          /usr/lib/ghc-9.4.8/site-local/getopt-generics-0.13.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/getopt-generics-0.13.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/getopt-generics-0.13.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-getopt-generics
hs-libraries:         HSgetopt-generics-0.13.1.0-45xXbNY05ppCTHFFBbj3aP
depends:
    base-4.17.2.1 base-compat-0.14.0-D6ySGt5shRqHRPQXrHl9Oo
    base-orphans-0.9.3-K0jSnIfYlPW34ZON03RGHV
    generics-sop-0.5.1.3-1cdm4H81rvrYJuJwoMQFY
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C

haddock-interfaces:
    /usr/share/doc/haskell-getopt-generics/html/getopt-generics.haddock

haddock-html:         /usr/share/doc/haskell-getopt-generics/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
